#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


require "mastercard/core/model"
require "mastercard/core/baseobject"

module MasterCard
	module API
		module Moneysend
			class CardMapping < MasterCard::Core::Model::BaseObject
				include MasterCard::Core::Model
				#

				@__store = {
					'd39dda38-e867-4d7f-93f8-658c2ece07e2' => OperationConfig.new("/moneysend/v3/mapping/card", "create", [], []),
					'8ed8856e-5acc-477e-91ec-e8e42cfd4776' => OperationConfig.new("/moneysend/v3/mapping/card/{mappingId}", "delete", [], []),
					'4e2db90f-1051-457d-856c-645f7c95cb63' => OperationConfig.new("/moneysend/v3/mapping/subscriber", "update", [], []),
					'c17fff52-7d25-430c-9e87-8590bb8f6fe6' => OperationConfig.new("/moneysend/v3/mapping/card", "update", [], []),
					'631bcad2-b81f-4a2f-8bd5-6afe7d6bc162' => OperationConfig.new("/moneysend/v3/mapping/card/{mappingId}", "update", [], []),
					
				}

				protected

				def self.getOperationConfig(uuid)
					if @__store.key?(uuid)
						return @__store[uuid]
					end
					raise NotImplementedError.new("Invalid operationUUID supplied:"+ uuid)
				end

				def self.getOperationMetadata()
					return OperationMetadata.new(ResourceConfig.instance.getVersion(), ResourceConfig.instance.getHost(), ResourceConfig.instance.getContext())
				end

				public


				def self.create(mapObj)
					#
					#Creates object of type CardMapping
					#
					#@param Dict mapObj, containing the required parameters to create a new object
					#@return [CardMapping] of the response of created instance.
					#@raise [APIException] an exception from the response status
					return self.execute("d39dda38-e867-4d7f-93f8-658c2ece07e2", CardMapping.new(mapObj))
				end










				def self.deleteById(id, map = nil)
					#Delete object of type CardMapping by id

					#@param [String] id
					#@param [Dict] map, containing additional parameters
					#@return [CardMapping] of the response of the deleted instance.
					#@raise [APIException] an exception from the response status


					mapObj = CardMapping.new
					if !(id.nil? || id.to_s.empty?)
					  mapObj.set("id", id)
					end
					if !map.nil?
						if map.instance_of? RequestMap
						  mapObj.setAll(map.getObject())
						else
						  mapObj.setAll(map)
						end
					end

					return self.execute("8ed8856e-5acc-477e-91ec-e8e42cfd4776", mapObj)
				end


				def delete
					#
					#Delete object of type CardMapping

					#@param [String] id
					#@return [CardMapping] of the response of the deleted instance.
					#@raise [APIException] an exception from the response status
					#

					return self.class.execute("8ed8856e-5acc-477e-91ec-e8e42cfd4776", self)
				end





				def deleteSubscriberID
					#
					#Updates an object of type CardMapping
					#
					#@return [CardMapping] object representing the response.
					#@raise [APIException] an exception from the response status
					#
					return self.class.execute("4e2db90f-1051-457d-856c-645f7c95cb63",self)
				end








				def read
					#
					#Updates an object of type CardMapping
					#
					#@return [CardMapping] object representing the response.
					#@raise [APIException] an exception from the response status
					#
					return self.class.execute("c17fff52-7d25-430c-9e87-8590bb8f6fe6",self)
				end








				def update
					#
					#Updates an object of type CardMapping
					#
					#@return [CardMapping] object representing the response.
					#@raise [APIException] an exception from the response status
					#
					return self.class.execute("631bcad2-b81f-4a2f-8bd5-6afe7d6bc162",self)
				end







			end
		end
	end
end







